/**
 * sipML5の操作クラス
 */
 class Call {
  constructor() {
    this.OPTIONS = {
      debug_level: 'info',
      register_config: {
        expires: 200,
      },
      realm: 'signal.mobabiji.jp',
      websocket_url: 'wss://signal.mobabiji.jp/ws',
      ice_servers: [
        {url: 'stun:turn.mobabiji.jp:443'},
        {url: 'turn:turn.mobabiji.jp:443', username: 'webrtc', credential: 'mypassword'}
      ],
      session_config: {
        audio_remote: document.getElementById("audio_remote"),
      },
      sounds: {
        dialtone: document.getElementById("dialtone"),
        ringbacktone: document.getElementById("ringbacktone"),
        busytone: document.getElementById("busytone"),
      },
      delegate: {
        onIncomingCall: (e) => { this.onIncomingCall(e); },
        onEstablishedCall: (e) => { this.onEstablishedCall(e); },
        onTerminatedCall: (e) => { this.onTerminatedCall(e); },
        onStartFailed: (e) => { alert('WebRTCサーバとの通信に失敗しました'); },
      },
    };
  }

  /**
   * 初期化
   * 
   * @param {string} username 内線番号
   * @param {string} password パスワード
   * @param {object} callBtn 発信ボタン(HTMLElement)、省略可
   */
  init(username, password, callBtn) {
    this.OPTIONS['username'] = username; // 内線番号
    this.OPTIONS['password'] = password; // パスワード
    this.callBtn = callBtn;
    if (this.callBtn) {
      $(this.callBtn).attr('data-status', 'none');
    }
    this.webrtc = new WebRTC(this.OPTIONS);
  }

  /**
   * 電話の発信
   * 
   * @param {string} telnum 発信先電話番号
   */
  call(telnum) {
    if (!this.webrtc.hasCall()) {
      if (this.webrtc.call(telnum, 'call-audio')) {
        if (this.callBtn) {
          $(this.callBtn).attr('data-status', 'call');
        }
      }
    } else {
      this.webrtc.hangup();
    }
  }

  /**
   * 通話の終了
   */
  hangup() {
    this.webrtc.hangup();
  }

  onIncomingCall(e) {
    // 着信はしない
    e.newSession.hangup();
  }

  onEstablishedCall(e) {
    if (this.callBtn) {
      $(this.callBtn).attr('data-status', 'call');
    }
  }

  onTerminatedCall(e) {
    if (this.callBtn) {
      $(this.callBtn).attr('data-status', 'none');
    }
  }
}

call = new Call();
